@@ -43,7 +43,7 @@ from typing import Any, Optional, Tuple, List, Set, Dict, Union, Callable, cast
 
 from DHParser.configuration import get_config_value
 from DHParser.preprocess import PreprocessorFunc
-from DHParser.nodetree import Node, RootNode, EMPTY_PTYPE, TreeContext
+from DHParser.nodetree import Node, RootNode, EMPTY_PTYPE, Trail
 from DHParser.transform import TransformerCallable
 from DHParser.parse import Grammar
 from DHParser.preprocess import gen_neutral_srcmap_func
@@ -130,7 +130,24 @@ class Compiler:
     method which will pick the right `on_XXX`-method. It is not
     recommended to call the `on_XXX`-methods directly.
 
-    :ivar context:  A list of parent nodes that ends with the currently
+    Variables that are (re-)set only in the constructor and retain their
+    value if changed during subesquent calls::
+
+    :ivar forbid_returning_None:  Default value: True. Most of the time,
+            if a compiler-method (i.e. on_XXX()) returns None, this is
+            a mistake due to a forgotten return statement. The method
+            compile() checks for this mistake and raises an error if
+            a compiler-method returns None. However, some compilers require
+            the possibility to return None-values. In this case
+            ``forbis_returing_None`` should be set to False in the constructor
+            of the derived class.
+
+            (Another Alternativ would be to return a sentinel object instead of
+            None.)
+
+    Object-Variables that are reset after each call of the Compiler-object::
+
+    :ivar trail:  A list of parent nodes that ends with the currently
                 compiled node.
     :ivar tree: The root of the abstract syntax tree.
     :ivar finalizers:  A stack of tuples (function, parameters) that will be
@@ -156,12 +173,16 @@ class Compiler:
     def __init__(self):
         self.has_attribute_visitors = any(field[0:5] == 'attr_' and callable(getattr(self, field))
                                           for field in dir(self))
+        self.forbid_returning_None = True  # type: bool
         self.reset()
 
     def reset(self):
+        """
+        Resets alls variables to their default values before the next call
+        of the object.
+        """
         self.tree = ROOTNODE_PLACEHOLDER   # type: RootNode
-        self.context = []  # type: TreeContext
-        self._None_check = True  # type: bool
+        self.trail = []  # type: Trail
         self._dirty_flag = False
         self._debug = get_config_value('debug_compiler')  # type: bool
         self._debug_already_compiled = set()              # type: Set[Node]
@@ -179,7 +200,7 @@ class Compiler:
     def finalize(self, result: Any) -> Any:
         """
         A finalization method that is called after compilation has finished and
-        after all tasks from the finalizers stack have been executed
+        after all tasks from the finalizers-stack have been executed
         """
         return result
 
@@ -195,7 +216,7 @@ class Compiler:
         required before the compilation and the finalization the compilation
         has been finished by taking the following steps::
 
-            1. reset all variables and initalize ``self.tree`` with ``root``
+            1. reset all variables and initialize ``self.tree`` with ``root``
             2. call the :py:meth:`Compiler.prepare()`-method.
             3. compile the syntax-tree originating in ``root`` by calling
                :py:meth:`Compiler.compile()` on the root-node.
@@ -221,15 +242,17 @@ class Compiler:
 
     def visit_attributes(self, node) -> Node:
         if node.has_attr():
+            self.trail.append(node)
             for attribute, value in list(node.attr.items()):
                 try:
                     attribute_visitor = self.__getattribute__(attr_visitor_name(attribute))
                     node = attribute_visitor(node, value) or node
                 except AttributeError:
                     pass
+            self.trail.pop()
         return node
 
-    def fallback_compiler(self, node: Node, block_attribute_visitors: bool=False) -> Any:
+    def fallback_compiler(self, node: Node) -> Any:
         """This is a generic compiler function which will be called on
         all those node types for which no compiler method `on_XXX` has
         been defined."""
@@ -256,11 +279,11 @@ class Compiler:
                     if nd is not None and nd.name != EMPTY_PTYPE:
                         result.append(nd)
                 node.result = tuple(result)
-        if self.has_attribute_visitors and not block_attribute_visitors:
+        if self.has_attribute_visitors:
             node = self.visit_attributes(node)
         return node
 
-    def get_compiler(self, node_name: str) -> CompilerFunc:
+    def find_compilation_method(self, node_name: str) -> CompilerFunc:
         try:
             method = self.method_dict[node_name]
         except KeyError:
@@ -292,16 +315,18 @@ class Compiler:
         elem = node.name
         if elem[:1] == ':':
             elem = elem[1:] + '__'
-        compiler = self.get_compiler(elem)
-        self.context.append(node)
-        result = compiler(node)
-        self.context.pop()
-        if result is None and self._None_check:
+        compiler = self.find_compilation_method(elem)
+        self.trail.append(node)
+        result = compiler(node)     
+        self.trail.pop()
+        if self.has_attribute_visitors:
+            node = self.visit_attributes(node)          
+        if result is None and self.forbid_returning_None:
             raise CompilerError(
                 ('Method on_%s returned `None` instead of a valid compilation '
                  'result! It is recommended to use `nodetree.EMPTY_NODE` as a '
                  'void value. This Error can be turn off by adding '
-                 '`self._None_check = False` to the reset()-Method of your'
+                 '`self.forbid_returning_None = False` to the reset()-Method of your'
                  'compiler class, in case on_%s actually SHOULD be allowed to '
                  'return None.') % (elem, elem))
         return result
@@ -322,6 +347,9 @@ def logfile_basename(filename_or_text, function_or_class_or_instance) -> str:
         return name[:i] + '_out' if i >= 0 else name
 
 
+# processing pipeline support #########################################
+
+
 CompilerCallable = Union[Compiler, Callable[[RootNode], Any], functools.partial]
 CompilerFactory = Union[Callable[[], CompilerCallable], functools.partial]
 
@@ -367,8 +395,8 @@ def process_tree(tp: CompilerCallable, tree: RootNode) -> Any:
             try:
                 result = tp(tree)
             except Exception as e:
-                # node = tp.context[-1] if hasattr(tp, 'context') and tp.context else tree
-                node = getattr(tp, 'context', [tree])[-1]
+                # node = tp.trail[-1] if hasattr(tp, 'trail') and tp.trail else tree
+                node = getattr(tp, 'trail', [tree])[-1]
                 st = traceback.format_list(traceback.extract_tb(e.__traceback__))
                 trace = ''.join(st)  # filter_stacktrace(st)
                 tree.new_error(
@@ -389,6 +417,19 @@ Junction = Tuple[str, CompilerFactory, str]
 def run_pipeline(junctions: Set[Junction],
                  source_stages: Dict[str, RootNode],
                  target_stages: Set[str]) -> Dict[str, Tuple[Any, List[Error]]]:
+    """
+    Runs all the intermediary compilation-steps that are necessary to produce
+    the "target-stages" from the given "source-stages". Here, each source-stage
+    consists of a name for that stage, say "AST", and a node-tree that
+    represents the data at this stage of the processing pipeline. In the
+    target-stage, the data can be a node-tree or data of any other kind.
+
+    The stages or connected through chains of junctions, where a junction is
+    essentially a function that transforms a tree from one particular stage
+    (identified by its name) to another stage, again itentified by its name.
+
+    TODO: Parallelize processing of junctions
+    """
     t_to_j = {j[-1]: j for j in junctions}
     steps = []
     targets = target_stages.copy()
