@@ -50,7 +50,7 @@ column-number
 from collections import namedtuple
 import functools
 import os
-from typing import Iterable, Iterator, Union, List, Sequence, NamedTuple, Dict, Callable
+from typing import Iterable, Iterator, Union, List, Sequence, Dict, Callable
 
 from DHParser.stringview import StringView
 from DHParser.toolkit import linebreaks, line_col, is_filename
@@ -81,23 +81,32 @@ __all__ = ('SourceMap',
            'UNDEFINED_SYMBOL_IN_TRANSTABLE_WARNING',
            'CANNOT_VERIFY_TRANSTABLE_WARNING',
            'CAPTURE_DROPPED_CONTENT_WARNING',
+           'ZERO_LENGTH_CAPTURE_POSSIBLE_WARNING',
            'OPTIONAL_REDUNDANTLY_NESTED_WARNING',
            'UNCONNECTED_SYMBOL_WARNING',
            'REORDERING_OF_ALTERNATIVES_REQUIRED',
            'MANDATORY_CONTINUATION',
            'MANDATORY_CONTINUATION_AT_EOF',
+           'MANDATORY_CONTINUATION_AT_EOF_NON_ROOT',
+           'CAPTURE_STACK_NOT_EMPTY_NON_ROOT_ONLY',
+           'AUTOCAPTURED_SYMBOL_NOT_CLEARED_NON_ROOT',
+           'ERROR_WHILE_RECOVERING_FROM_ERROR',
+           'PARSER_NEVER_TOUCHES_DOCUMENT',
            'PARSER_NEVER_TOUCHES_DOCUMENT',
            'PARSER_LOOKAHEAD_FAILURE_ONLY',
            'PARSER_STOPPED_BEFORE_END',
+           'PARSER_STOPPED_ON_RETRY',
            'PARSER_LOOKAHEAD_MATCH_ONLY',
            'CAPTURE_STACK_NOT_EMPTY',
-           'AUTORETRIEVED_SYMBOL_NOT_CLEARED',
+           'CAPTURE_STACK_NOT_EMPTY_WARNING',
+           'AUTOCAPTURED_SYMBOL_NOT_CLEARED',
            'MALFORMED_ERROR_STRING',
            'AMBIGUOUS_ERROR_HANDLING',
            'REDEFINED_DIRECTIVE',
            'UNDEFINED_RETRIEVE',
            'DIRECTIVE_FOR_NONEXISTANT_SYMBOL',
            'INAPPROPRIATE_SYMBOL_FOR_DIRECTIVE',
+           'PEG_EXPRESSION_IN_DIRECTIVE_WO_BRACKETS',
            'CAPTURE_WITHOUT_PARSERNAME',
            'LOOKAHEAD_WITH_OPTIONAL_PARSER',
            'BADLY_NESTED_OPTIONAL_PARSER',
@@ -107,6 +116,7 @@ __all__ = ('SourceMap',
            'BAD_REPETITION_COUNT',
            'MALFORMED_REGULAR_EXPRESSION',
            'EMPTY_GRAMMAR_ERROR',
+           'STRUCTURAL_ERROR_IN_AST',
            'TREE_PROCESSING_CRASH',
            'COMPILER_CRASH',
            'AST_TRANSFORM_CRASH',
@@ -141,7 +151,7 @@ SourceMap = namedtuple('SourceMap',
      'offsets',  # type: List[int]
      'file_names',  # type: List[str]
      'originals_dict',  # type: Dict[str, Union[str, StringView]]
-    ], module = __name__)
+    ], module=__name__)
 
 # class SourceLocation(NamedTuple):
 #     original_name: str          # the file name (or path or uri) of the source code
@@ -157,7 +167,7 @@ SourceLocation = namedtuple('SourceLocation',
     ['original_name',  # type: str
      'original_text',  # type: Union[str, StringView]
      'pos',  # type: int
-    ], module = __name__)
+    ], module=__name__)
 
 SourceMapFunc = Union[Callable[[int], SourceLocation],
                       functools.partial]
@@ -196,8 +206,10 @@ LEFT_RECURSION_WARNING                   = ErrorCode(140)  # obsolete!
 UNDEFINED_SYMBOL_IN_TRANSTABLE_WARNING   = ErrorCode(610)
 CANNOT_VERIFY_TRANSTABLE_WARNING         = ErrorCode(620)
 CAPTURE_DROPPED_CONTENT_WARNING          = ErrorCode(630)
-OPTIONAL_REDUNDANTLY_NESTED_WARNING      = ErrorCode(630)
-UNCONNECTED_SYMBOL_WARNING               = ErrorCode(640)
+CAPTURE_STACK_NOT_EMPTY_WARNING          = ErrorCode(640)
+ZERO_LENGTH_CAPTURE_POSSIBLE_WARNING     = ErrorCode(650)
+OPTIONAL_REDUNDANTLY_NESTED_WARNING      = ErrorCode(660)
+UNCONNECTED_SYMBOL_WARNING               = ErrorCode(670)
 
 REORDERING_OF_ALTERNATIVES_REQUIRED      = ErrorCode(710)
 
@@ -205,20 +217,27 @@ REORDERING_OF_ALTERNATIVES_REQUIRED      = ErrorCode(710)
 
 MANDATORY_CONTINUATION                   = ErrorCode(1010)
 MANDATORY_CONTINUATION_AT_EOF            = ErrorCode(1015)
+MANDATORY_CONTINUATION_AT_EOF_NON_ROOT   = ErrorCode(1017)
 PARSER_NEVER_TOUCHES_DOCUMENT            = ErrorCode(1020)
 PARSER_LOOKAHEAD_FAILURE_ONLY            = ErrorCode(1030)
 PARSER_STOPPED_BEFORE_END                = ErrorCode(1040)
+PARSER_STOPPED_ON_RETRY                  = ErrorCode(1042)
 PARSER_LOOKAHEAD_MATCH_ONLY              = ErrorCode(1045)
 CAPTURE_STACK_NOT_EMPTY                  = ErrorCode(1050)
-AUTORETRIEVED_SYMBOL_NOT_CLEARED         = ErrorCode(1055)
+CAPTURE_STACK_NOT_EMPTY_NON_ROOT_ONLY    = ErrorCode(1052)
+AUTOCAPTURED_SYMBOL_NOT_CLEARED          = ErrorCode(1055)
+AUTOCAPTURED_SYMBOL_NOT_CLEARED_NON_ROOT = ErrorCode(1057)
 MALFORMED_ERROR_STRING                   = ErrorCode(1060)
 AMBIGUOUS_ERROR_HANDLING                 = ErrorCode(1070)
 REDEFINED_DIRECTIVE                      = ErrorCode(1080)
 UNDEFINED_RETRIEVE                       = ErrorCode(1090)
 DIRECTIVE_FOR_NONEXISTANT_SYMBOL         = ErrorCode(1100)
 INAPPROPRIATE_SYMBOL_FOR_DIRECTIVE       = ErrorCode(1110)
+PEG_EXPRESSION_IN_DIRECTIVE_WO_BRACKETS  = ErrorCode(1120)
 
-# EBNF-specific static analysis errors
+ERROR_WHILE_RECOVERING_FROM_ERROR        = ErrorCode(1301)
+
+# EBNF-specific and static analysis errors
 
 CAPTURE_WITHOUT_PARSERNAME               = ErrorCode(1510)
 LOOKAHEAD_WITH_OPTIONAL_PARSER           = ErrorCode(1520)
@@ -236,6 +255,7 @@ TREE_PROCESSING_CRASH                    = ErrorCode(10100)
 COMPILER_CRASH                           = ErrorCode(10200)
 AST_TRANSFORM_CRASH                      = ErrorCode(10300)
 RECURSION_DEPTH_LIMIT_HIT                = ErrorCode(10400)
+STRUCTURAL_ERROR_IN_AST                  = ErrorCode(10500)
 
 
 #######################################################################
@@ -252,14 +272,24 @@ class Error:
     :ivar message:  the error message as text string
     :ivar pos:  the position where the error occurred in the preprocessed text
     :ivar code:  the error-code, which also indicates the severity of the
-        error. 0:        no error
-               < 100:    notice
-               < 1000:   warning
-               < 10000:  error
-               >= 10000: fatal error. syntax tree will not be passed on to
-                         the next compilation stage!
+        error::
+
+               ========= ===========
+               code      severity
+               ========= ===========
+               0         no error
+               < 100     notice
+               < 1000    warning
+               < 10000   error
+               >= 10000  fatal error
+               ========= ===========
+
+        In cas of a fatal error (error code >= 10000), no further compilation
+        stages will be processed, because it is assumed that the syntax tree
+        is too distorted for further processing.
+
     :ivar orig_pos:  the position of the error in the original source file,
-        not in the preprocessed document. This is a write once value!
+        not in the preprocessed document. This is a write-once value!
     :ivar orig_doc:  the name or path or url of the original source file to
         which ``orig_pos`` is related. This is relevant, if the preprocessed
         document has been plugged together from several source files.
@@ -291,7 +321,7 @@ class Error:
         self.message = message    # type: str
         self._pos = pos           # type: int
         # Add some logic to avoid double assignment of the same error code?
-        # Problem: Same code might allowedly be used by two different parsers/compilers
+        # Problem: Same code might legitimately be used by two different parsers/compilers
         self.code = code          # type: ErrorCode
         self.orig_pos = orig_pos  # type: int
         self.orig_doc = orig_doc  # type: str
@@ -304,10 +334,19 @@ class Error:
         self.end_column = -1      # type: int
         self.related = tuple(related)   # type: Sequence['Error']
 
+    def __eq__(self, other):
+        return self.message == other.message and self.code == other.code \
+               and self._pos == other._pos  # and self.length == other.length
+
+    def __hash__(self):
+        return hash((self.message, self.code, self._pos))
+
     def __str__(self):
-        prefix = ''
+        if self.orig_doc and self.orig_doc != 'UNKNOWN_FILE':
+            prefix = self.orig_doc + ':'
+        else:  prefix = ''
         if self.line > 0:
-            prefix = "%i:%i: " % (max(self.line, 0), max(self.column, 0))
+            prefix += "%i:%i: " % (max(self.line, 0), max(self.column, 0))
         return prefix + "%s (%i): %s" % (self.severity, self.code, self.message)
 
     def __repr__(self):
@@ -321,7 +360,7 @@ class Error:
     @pos.setter
     def pos(self, value: int):
         self._pos = value
-        # reset line and column values, because they might now not be valid any more
+        # reset line and column values, because they might now not be valid anymore
         self.orig_pos = -1
         self.line, self.column = -1, -1
         self.end_line, self.end_column = -1, -1
@@ -358,7 +397,7 @@ class Error:
                 'end': {'line': self.end_line - 1, 'character': self.end_column - 1}}
 
     def diagnosticObj(self) -> dict:
-        """Returns the Error as as Language Server Protocol Diagnostic object.
+        """Returns the Error as Language Server Protocol Diagnostic object.
         https://microsoft.github.io/language-server-protocol/specifications/specification-current/#diagnostic
         """
         def relatedObj(relatedError: 'Error') -> dict:
@@ -387,6 +426,7 @@ class Error:
             diagnostic['relatedInformation'] = [relatedObj(err) for err in self.related]
         return diagnostic
 
+
 def is_warning(code: Union[Error, int]) -> bool:
     """Returns True, if error is merely a warning or a message."""
     if isinstance(code, Error):  code = code.code
@@ -452,8 +492,6 @@ def add_source_locations(errors: List[Error], source_mapping: SourceMapFunc):
     Args:
         errors:  The list of errors as returned by the method
             ``errors()`` of a Node object
-        original_text:  The source text in which the errors occurred.
-            (Needed in order to determine the line and column numbers.)
         source_mapping:  A function that maps error positions to their
             positions in the original source file.
     """
@@ -461,7 +499,7 @@ def add_source_locations(errors: List[Error], source_mapping: SourceMapFunc):
     for err in errors:
         if err.pos < 0:
             raise ValueError(f'Illegal error position: {err.pos} Must be >= 0!')
-        if err.orig_pos < 0:  # do not overwriter oirg_pos if already set
+        if err.orig_pos < 0:  # do not overwrite orig_pos if already set
             err.orig_doc, orig_text, err.orig_pos = source_mapping(err.pos)
             lbreaks = lb_dict.setdefault(orig_text, linebreaks(orig_text))
             err.line, err.column = line_col(lbreaks, err.orig_pos)
@@ -478,16 +516,17 @@ def canonical_error_strings(errors: List[Error]) -> List[str]:
         error_strings = []
         for err in errors:
             source_file_name = err.orig_doc
-            if is_filename(source_file_name):
+            if source_file_name and is_filename(source_file_name):
                 cwd = os.getcwd()
                 if source_file_name.startswith(cwd):
                     rel_path = source_file_name[len(cwd)]
                 else:
                     rel_path = source_file_name
-                error_strings.append(rel_path + ':' + str(err))
+                err_str = str(err)
+                err_str = err_str[err_str.find(':'):]
+                error_strings.append(rel_path + err_str)
             else:
                 error_strings.append(str(err))
     else:
         error_strings = []
     return error_strings
-
