@@ -34,14 +34,14 @@ from DHParser import start_logging, suspend_logging, resume_logging, is_filename
     ZeroOrMore, Forward, NegativeLookahead, Required, mixin_comment, compile_source, \
     grammar_changed, last_value, matching_bracket, PreprocessorFunc, is_empty, remove_if, \
     Node, TransformerCallable, TransformationDict, transformation_factory, traverse, \
-    remove_children_if, move_fringes, normalize_whitespace, is_anonymous, matches_re, \
+    remove_children_if, move_fringes, normalize_whitespace, is_anonymous, name_matches, \
     reduce_single_child, replace_by_single_child, replace_or_reduce, remove_whitespace, \
     replace_by_children, remove_empty, remove_tokens, flatten, all_of, any_of, \
-    merge_adjacent, collapse, collapse_children_if, transform_content, WHITESPACE_PTYPE, \
+    merge_adjacent, collapse, collapse_children_if, transform_result, WHITESPACE_PTYPE, \
     TOKEN_PTYPE, remove_children, remove_content, remove_brackets, change_name, \
-    remove_anonymous_tokens, keep_children, is_one_of, not_one_of, has_content, apply_if, peek, \
+    remove_anonymous_tokens, keep_children, is_one_of, not_one_of, content_matches, apply_if, peek, \
     remove_anonymous_empty, keep_nodes, traverse_locally, strip, lstrip, rstrip, \
-    transform_content, replace_content_with, forbid, assert_content, remove_infix_operator, \
+    replace_content_with, forbid, assert_content, remove_infix_operator, \
     add_error, error_on, recompile_grammar, left_associative, lean_left, set_config_value, \
     get_config_value, node_maker, access_thread_locals, access_presets, has_children, \
     finalize_presets, ErrorCode, RX_NEVER_MATCH, set_tracer, resume_notices_on, \
@@ -92,7 +92,7 @@ class LaTeXGrammar(Grammar):
     paragraph = Forward()
     param_block = Forward()
     tabular_config = Forward()
-    source_hash__ = "da56d9c0377d8edee466c5d2a4b75e98"
+    source_hash__ = "09209816912c3c12efbd07233f9a14bf"
     disposable__ = re.compile('_\\w+')
     static_analysis_pending__ = []  # type: List[bool]
     parser_initialization__ = ["upon instantiation"]
@@ -417,14 +417,13 @@ LaTeX_AST_transformation_table = {
     "cfg_text": [reduce_single_child],
     "block": [reduce_single_child],
     "flag": [reduce_single_child],
-    "text": collapse,
-    "path": collapse,
+    "text, urlstring": collapse,
     "no_command, blockcmd": [],
     "_structure_name": [],
     "CMDNAME": [remove_whitespace, reduce_single_child],
     "TXTCOMMAND": [remove_whitespace, reduce_single_child],
     "NAME": [reduce_single_child, remove_whitespace, reduce_single_child],
-    "ESCAPED": [apply_ifelse(transform_content(lambda result: result[1:]),
+    "ESCAPED": [apply_ifelse(transform_result(lambda result: result[1:]),
                              replace_content_with('~'),
                              lambda ctx: '~' not in ctx[-1].content)],
     "UMLAUT": replace_Umlaut,
